import React from 'react';
import ReactMarkdown from 'react-markdown';
import remarkGfm from 'remark-gfm';
import { FileWarning } from 'lucide-react';

interface ProjectsContentProps {
  markdownPath: string;
}

const ProjectsContent: React.FC<ProjectsContentProps> = ({ markdownPath }) => {
  const [content, setContent] = React.useState<string>('');
  const [error, setError] = React.useState<string>('');

  React.useEffect(() => {
    fetch(markdownPath)
      .then(response => {
        if (!response.ok) throw new Error('Failed to load content');
        return response.text();
      })
      .then(text => setContent(text))
      .catch(err => setError(err.message));
  }, [markdownPath]);

  if (error) {
    return (
      <div className="flex-1 flex items-center justify-center">
        <div className="text-center space-y-4">
          <FileWarning className="w-12 h-12 mx-auto" />
          <p className="text-lg">Error loading content: {error}</p>
        </div>
      </div>
    );
  }

  return (
    <div className="flex-1">
      <div className="prose prose-invert prose-green max-w-none">
        <ReactMarkdown remarkPlugins={[remarkGfm]}>
          {content}
        </ReactMarkdown>
      </div>
    </div>
  );
};

export default ProjectsContent;
